/*
 * Copyright (c) 2012 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licensing information.
 */
package pl.edu.icm.uvos.webapp.data;

import javax.servlet.ServletConfig;

import org.apache.log4j.Logger;
import org.picocontainer.PicoContainer;
import org.springframework.web.context.ServletConfigAware;

import pl.edu.icm.unicore.uvos.server.JettyServer;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import eu.emi.security.authn.x509.X509CertChainValidator;
import eu.unicore.util.Log;

/**
 * @author K. Benedyczak
 */
public class ValidatorProviderImpl implements ValidatorProvider, ServletConfigAware
{
	private static final Logger log = Log.getLogger(LogConfig.PFX, ValidatorProviderImpl.class);

	private X509CertChainValidator validator;
	
	@Override
	public void setServletConfig(ServletConfig srvCfg)
	{
		PicoContainer pico = (PicoContainer) srvCfg.getServletContext().getAttribute(JettyServer.UVOS_SERVER_CONTAINER_REFERENCE);
		if (pico == null) 
			log.fatal("Can't get PicoContainer from the servlet context. Either" +
				" you deployed this servlet to an other than UVOS container " +
				" or to UVOS server with version < 1.6.0");
		UVOSServerProperties cfg = pico.getComponent(UVOSServerProperties.class);
		validator = cfg.getAuthAndTrust().getValidator();
	}

	@Override
	public X509CertChainValidator getValidator()
	{
		return validator;
	}
}
